@@ -27,12 +27,12 @@
 #include <string.h>
 #endif
 
-#if defined(linux) || defined(__DragonFly__) || defined(macosx)
+#if defined(linux) || defined(__DragonFly__) || defined(IOZ_macosx)
 #include <unistd.h>
 #include <stdlib.h>
 #endif
 
-#if ((defined(solaris) && defined( __LP64__ )) || defined(__s390x__))
+#if (defined(solaris) && defined( __LP64__ )) || defined(__s390x__) || defined(FreeBSD)
 /* If we are building for 64-bit Solaris, all functions that return pointers
  * must be declared before they are used; otherwise the compiler will assume
  * that they return ints and the top 32 bits of the pointer will be lost,
@@ -91,7 +91,7 @@ void do_label(int,char *,int,int);
 /*	  column							*/
 /************************************************************************/
 
-char libbif_version[] = "Libbif Version $Revision: 3.24 $";
+char libbif_version[] = "Libbif Version $Revision: 3.26 $";
 void do_eof(int );		/* Used internally */
 void do_header(int );		/* Used internally */
 int endian(void);
